pub struct TextMetrics {
pub width: f32,
pub ascent: f32,
pub descent: f32,
}Expand description
Shaped-line metrics returned by canvas_measure_text. All values are in pixels.
Fields
width: f32Advance width of the shaped line.
ascent: f32Distance from baseline to the top of the tallest glyph (positive).
descent: f32Distance from baseline to the bottom of the lowest glyph (positive).